/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, Input, OnInit, ViewEncapsulation } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";
import {CapabilityVersion} from "../../../../model/capability-version";

@Component({
  selector: "app-parameters",
  templateUrl: "./parameters.component.html",
  styleUrls: ["./parameters.component.scss"],
  encapsulation: ViewEncapsulation.None
})
export class ParametersComponent implements OnInit {
  @Input() currentVersion: CapabilityVersion;

  constructor() {}

  ngOnInit(): void {}

  /**
   * Check if JsonObject is empty
   * Taken from: https://stackoverflow.com/questions/679915/how-do-i-test-for-an-empty-javascript-object
   * @param obj  Object to be checked
   * @return boolean  true if object is empty; else false
   */
  isEmpty(obj: JsonObject): boolean {
    for (const prop in obj) {
      if (obj.hasOwnProperty(prop)) {
        return false;
      }
    }

    return true;
  }

  copyToClipboard(text: string, id: string): void {
    const selBox = document.createElement('textarea');
    selBox.style.position = 'fixed';
    selBox.style.left = '0';
    selBox.style.top = '0';
    selBox.style.opacity = '0';
    selBox.value = text;
    document.body.appendChild(selBox);
    selBox.focus();
    selBox.select();
    document.execCommand('copy');
    document.body.removeChild(selBox);

    // animate copy-to-clipboard
    const paramCopySpan = document.querySelector(".paramCopyEvent#" + id + ":not(.animate)");
    if(paramCopySpan) {
      paramCopySpan.classList.add('animate');
      paramCopySpan.addEventListener('animationend', () => paramCopySpan.classList.remove('animate') );
    }
  }

}
