#
# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""vlass_coarse_workflow_addition

Revision ID: 31041572e828
Revises: 416734492102
Create Date: 2022-06-13 10:41:11.872316

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "31041572e828"
down_revision = "416734492102"
branch_labels = None
depends_on = None


# vlass_coarse.dag
vlass_coarse_dag_content = """JOB FETCH vlass_coarse_fetch.condor
VARS FETCH jobname="$(JOB)"

JOB ENVOY vlass_coarse_envoy.condor
VARS ENVOY jobname="$(JOB)"

PARENT FETCH CHILD ENVOY

"""

# vlass_coarse_fetch.sh
vlass_coarse_fetch_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../

"""

# vlass_coarse_fetch.condor
vlass_coarse_fetch_condor = """executable = vlass_coarse_fetch.sh
arguments = {{product_locator}}

output = vlass_coarse_fetch.out
error = vlass_coarse_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/productfetcher, nraorsync://{{rawdata_dir}}
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

# vlass_coarse_envoy.sh
vlass_coarse_envoy_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

./casa_envoy --seci $1 $2
"""

# vlass_coarse_envoy.condor
vlass_coarse_envoy_condor = """executable = vlass_coarse.sh
arguments = metadata.json PPR.xml

output = vlass_coarse_envoy.out
error = vlass_coarse_env0y.err
log = condor.log

VLASS_DIR = {{data_location}}
SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/vela, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(VLASS_DIR)/working, nraorsync://$(VLASS_DIR)/rawdata, nraorsync://$(VLASS_DIR)/products, nraorsync://$(VLASS_DIR)/{{profile}}.properties, nraorsync://$(VLASS_DIR)/PPR.xml, nraorsync://$(VLASS_DIR)/metadata.json
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "rawdata working products"
output_destination = nraorsync://$(VLASS_DIR)
+WantIOProxy = True

request_memory = 50G
getenv = True
environment = "CAPO_PATH=."

{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""


def upgrade():

    op.execute(
        """
    INSERT INTO workflows (workflow_name, uses_casa) VALUES ('vlass_coarse', true);
    """
    )

    op.execute(
        f"""
    INSERT INTO workflow_templates (filename, content, workflow_name)
    VALUES ('vlass_coarse.dag', E'{vlass_coarse_dag_content}', 'vlass_coarse')
    """
    )

    op.execute(
        f"""
    INSERT INTO workflow_templates (filename, content, workflow_name)
    VALUES ('vlass_coarse_envoy.sh', E'{vlass_coarse_envoy_content}', 'vlass_coarse')
    """
    )

    op.execute(
        f"""
    INSERT INTO workflow_templates (filename, content, workflow_name)
    VALUES ('vlass_coarse_envoy.condor', E'{vlass_coarse_envoy_condor}', 'vlass_coarse')
    """
    )

    op.execute(
        f"""
    INSERT INTO workflow_templates (filename, content, workflow_name)
    VALUES ('vlass_coarse_fetch.sh', E'{vlass_coarse_fetch_content}', 'vlass_coarse')
    """
    )

    op.execute(
        f"""
    INSERT INTO workflow_templates (filename, content, workflow_name)
    VALUES ('vlass_coarse_fetch.condor', E'{vlass_coarse_fetch_condor}', 'vlass_coarse')
    """
    )


def downgrade():

    op.execute(
        """
    DELETE FROM workflows WHERE workflow_name = 'vlass_coarse'
    """
    )

    op.execute(
        """
    DELETE FROM workflow_templates WHERE workflow_name = 'vlass_coarse'
    """
    )
